use std::error::Error;

use tokio::net::TcpStream;
use tokio_tungstenite::tungstenite::handshake::client::Response;
use tokio_tungstenite::{MaybeTlsStream, WebSocketStream};

use crate::data::GameRules;

pub async fn run_client(server: &str, rules: &GameRules) -> Result<(), Box<dyn Error>> {
    let url = format!(
        "{}/play/bot?{}",
        server.replace("http", "ws"),
        serde_urlencoded::to_string(rules).unwrap()
    );
    log::debug!("Connecting to  {}...", url);
    let (socket, _) = match tokio_tungstenite::connect_async(url).await {
        Ok(s) => s,
        Err(e) => {
            log::error!("Failed to establish WebSocket connection! {:?}", e);
            return Err(Box::new(e));
        }
    };

    Ok(())
}
